@@ -1000,7 +1000,12 @@ def check_components_parameter(components: list):
 
 
 def check_update_omixatlas_parameters(
-    display_name: str, description: str, repo_key: str, image_url: str, components: list
+    display_name: str,
+    description: str,
+    repo_key: str,
+    image_url: str,
+    components: list,
+    workspace_id: str,
 ):
     """Sanity check for Parameters passed in Update Method
     Args:
@@ -1009,22 +1014,29 @@ def check_update_omixatlas_parameters(
         repo_name (str): proposed repo name for the omixatlas
         image_url (str): image url provided for the icon for the omixatlas
         components (list): components to be added in the omixatlas
+        workspace_id (str): ID of the Workspace to be linked to the Omixatlas.
         data_type(str): datatype of the omixatlas. By default it is None
     """
     try:
         parameter_check_for_repo_id(repo_key)
         # this can be refactored using args -> just passing **args into the function
         # have a discussion on this
-        if not display_name and not description and not image_url and not components:
+        if (
+            not display_name
+            and not description
+            and not image_url
+            and not components
+            and not workspace_id
+        ):
             raise paramException(
                 title="Param Error",
                 detail=(
                     "No parameters passed to update, please pass at least one of the following"
-                    + " params [display_name, description, image_url, components, data_type]."
+                    + " params [display_name, description, image_url, components, workspace_id, data_type]."
                 ),
             )
 
-        str_params = [display_name, description, image_url]
+        str_params = [display_name, description, image_url, workspace_id]
         for param in str_params:
             if not isinstance(param, str):
                 raise paramException(
