@@ -71,8 +71,8 @@ def test_download_data():
     obj2 = omixatlas.OmixAtlas(token)
     repo_name = "elucidata.liveromix_atlas"
     d_id = "CCLE_metabolomics_LIVER"
-    assert obj2.download_data(repo_name, d_id)["data"] is not None
-    assert nobj2.download_data(repo_name, d_id)["data"] is not None
+    assert obj2.download_data(repo_name, d_id, internal_call=True)["data"] is not None
+    assert nobj2.download_data(repo_name, d_id, internal_call=True)["data"] is not None
 
 
 def test_add_dataset_str_type_source_folder_path():
